<?php
/*
	Plugin Name: Maximum image dimesions
    Plugin URI: http://www.duuuda.eu/
	Description: Setting up muximum image dimensions.
	Author: Saša Bilbija
    Author URI: http://www.duuuda.eu/
	Version: 1.0.0
*/

class Maximum_Image_Dimensions {
    
    public function __construct() {
        add_action( 'admin_init' , array( $this, 'init') );
    }
    
    public function init() {
        register_setting( 'media', 'max_image_width', array( $this, 'check_max_image_width') );
        register_setting( 'media', 'max_image_height', array( $this, 'check_max_image_height') );
        
        add_settings_field(
            'max_image_size',
            '<label for="max_image_width_id">' . __( 'Maximum image size' , 'maximum_image_dimensions' ) . '</label>',
            array( $this, 'fields_html'),
            'media'
        );
        
        add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), array( $this, 'plugin_action_links') );
        
        add_filter('wp_handle_upload', array( $this, 'handle_upload'), 10, 2 );
    }
    
    function plugin_action_links( $links ) {
       $links[] = '<a href="'. esc_url( get_admin_url(null, 'options-media.php') ) .'">Settings</a>';
       return $links;
    }
    
    public function fields_html() {
        $valueMaxWidth = get_option( 'max_image_width', '' );
        $valueMaxHeight = get_option( 'max_image_height', '' );
        echo '<fieldset><legend class="screen-reader-text"><span>' . __( 'Maximum image size' , 'maximum_image_dimensions' ) . '</span></legend>
    <label for="max_image_width_id">' . __( 'Max Width' , 'maximum_image_dimensions' ) . '</label>
    <input name="max_image_width" type="number" step="1" min="0" id="max_image_width_id" value="' . esc_attr( $valueMaxWidth ) . '" class="small-text">
    <label for="max_image_height_id">' . __( 'Max Height' , 'maximum_image_dimensions' ) . '</label>
    <input name="max_image_height" type="number" step="1" min="0" id="max_image_height_id" value="' . esc_attr( $valueMaxHeight ) . '" class="small-text">
    </fieldset><p class="description" id="">For unlimited width/height leave empty or 0.</p>';
    }

    public function check_max_image_width($option){
        $option = absint($option);
        if($option == 0){
            $option = "";
        }
        return $option;
    }

    public function check_max_image_height($option){
        $option = absint($option);
        if($option == 0){
            $option = "";
        }
        return $option;
    }
    
    public function handle_upload($array, $var){
        if((get_option( 'max_image_width', '' ) != 0 && get_option( 'max_image_width', '' ) != "") || (get_option( 'max_image_height', '' ) != 0 && get_option( 'max_image_height', '' ) != "") && ($array["type"] == "image/jpeg" || $array["type"] == "image/jpg" || $array["type"] == "image/gif" || $array["type"] == "image/png" || $array["type"] == "image/bmp")){
            $newWidth = get_option('max_image_width') == "" ? 0 : get_option('max_image_width');
            $newHeight = get_option('max_image_height') == "" ? 0 : get_option('max_image_height');
            
            $size = @getimagesize( $array["file"] );
            $imgWidth = $size[0];
            $imgHeight = $size[1];
            
            if($imgWidth > $newWidth || $imgHeight > $newHeight){

                $image = wp_get_image_editor( $array["file"] );
                
                if ( ! is_wp_error( $image ) ) {
                    $image->resize( $newWidth, $newHeight );
                    $newImage = $image->save( $array["file"] );
                }
            }
        }
        return $array;
    }
    
}

new Maximum_Image_Dimensions();

?>